@@ -2,21 +2,12 @@ import sys
 import weakref
 
 import kubernetes
-from dagster import (
-    DagsterInvariantViolationError,
-    EventMetadataEntry,
-    Field,
-    Noneable,
-    StringSource,
-    check,
-)
+from dagster import EventMetadataEntry, Field, Noneable, StringSource, check
 from dagster.cli.api import ExecuteRunArgs
 from dagster.core.events import EngineEventData
 from dagster.core.host_representation import ExternalPipeline
-from dagster.core.host_representation.handle import GrpcServerRepositoryLocationHandle
 from dagster.core.instance import DagsterInstance
 from dagster.core.launcher import RunLauncher
-from dagster.core.origin import PipelineGrpcServerOrigin, PipelinePythonOrigin
 from dagster.core.storage.pipeline_run import PipelineRun, PipelineRunStatus
 from dagster.serdes import ConfigurableClass, ConfigurableClassData, serialize_dagster_namedtuple
 from dagster.utils import frozentags, merge_dicts
@@ -59,7 +50,7 @@ class K8sRunLauncher(RunLauncher, ConfigurableClass):
             the Job.
         job_image (Optional[str]): The ``name`` of the image to use for the Job's Dagster container.
             This image will be run with the command
-            ``dagster api execute_run_with_structured_logs``.
+            ``dagster api execute_run``.
             When using user code deployments, the image should not be specified.
         instance_config_map (str): The ``name`` of an existing Volume to mount into the pod in
             order to provide a ConfigMap for the Dagster instance. This Volume should contain a
@@ -239,52 +230,26 @@ class K8sRunLauncher(RunLauncher, ConfigurableClass):
 
         user_defined_k8s_config = get_user_defined_k8s_config(frozentags(run.tags))
 
-        pipeline_origin = None
-        job_config = None
-        if isinstance(external_pipeline.get_origin(), PipelineGrpcServerOrigin):
-            if self._job_image:
-                raise DagsterInvariantViolationError(
-                    "Cannot specify job_image in run launcher config when loading pipeline "
-                    "from GRPC server."
-                )
+        pipeline_origin = external_pipeline.get_python_origin()
+        repository_origin = pipeline_origin.repository_origin
 
-            repository_location_handle = (
-                external_pipeline.repository_handle.repository_location_handle
-            )
-
-            if not isinstance(repository_location_handle, GrpcServerRepositoryLocationHandle):
-                raise DagsterInvariantViolationError(
-                    "Expected RepositoryLocationHandle to be of type "
-                    "GrpcServerRepositoryLocationHandle but found type {}".format(
-                        type(repository_location_handle)
-                    )
-                )
-
-            job_image = repository_location_handle.get_current_image()
-
-            job_config = self._get_grpc_job_config(job_image)
-
-            repository_name = external_pipeline.repository_handle.repository_name
-            pipeline_origin = PipelinePythonOrigin(
-                pipeline_name=external_pipeline.name,
-                repository_origin=repository_location_handle.reload_repository_python_origin(
-                    repository_name
-                ),
-            )
-        else:
-            pipeline_origin = external_pipeline.get_origin()
-            job_config = self._get_static_job_config()
+        job_config = (
+            self._get_grpc_job_config(repository_origin.container_image)
+            if repository_origin.container_image
+            else self._get_static_job_config()
+        )
 
         input_json = serialize_dagster_namedtuple(
             ExecuteRunArgs(
-                pipeline_origin=pipeline_origin, pipeline_run_id=run.run_id, instance_ref=None,
+                pipeline_origin=pipeline_origin,
+                pipeline_run_id=run.run_id,
+                instance_ref=None,
             )
         )
 
         job = construct_dagster_k8s_job(
             job_config=job_config,
-            command=["dagster"],
-            args=["api", "execute_run_with_structured_logs", input_json],
+            args=["dagster", "api", "execute_run", input_json],
             job_name=job_name,
             pod_name=pod_name,
             component="run_coordinator",
@@ -293,7 +258,7 @@ class K8sRunLauncher(RunLauncher, ConfigurableClass):
 
         self._batch_api.create_namespaced_job(body=job, namespace=self.job_namespace)
         self._instance.report_engine_event(
-            "Kubernetes run_coordinator job launched",
+            "Kubernetes run worker job launched",
             run,
             EngineEventData(
                 [
@@ -324,10 +289,6 @@ class K8sRunLauncher(RunLauncher, ConfigurableClass):
         if not run:
             return False
 
-        self._instance.report_engine_event(
-            message="Received pipeline termination request.", pipeline_run=run, cls=self.__class__
-        )
-
         can_terminate = self.can_terminate(run_id)
         if not can_terminate:
             self._instance.report_engine_event(
@@ -339,6 +300,8 @@ class K8sRunLauncher(RunLauncher, ConfigurableClass):
             )
             return False
 
+        self._instance.report_run_canceling(run)
+
         job_name = get_job_name_from_run_id(run_id)
 
         try:
