@@ -14,7 +14,7 @@ class K8sScheduler(Scheduler, ConfigurableClass):
 
     Enable this scheduler by adding it to your dagster.yaml, or by configuring the scheduler
     section of the Helm chart
-    https://github.com/dagster-io/dagster/tree/master/helm"""
+    https://github.com/dagster-io/dagster/tree/master/helm/dagster"""
 
     def __init__(
         self,
@@ -106,7 +106,7 @@ class K8sScheduler(Scheduler, ConfigurableClass):
     def _job_template(self, external_schedule):
         check.inst_param(external_schedule, "external_schedule", ExternalSchedule)
 
-        local_target = external_schedule.get_origin()
+        local_target = external_schedule.get_external_origin()
 
         job_config = self.job_config
 
@@ -116,8 +116,8 @@ class K8sScheduler(Scheduler, ConfigurableClass):
 
         job_template = construct_dagster_k8s_job(
             job_config=job_config,
-            command=["dagster"],
             args=[
+                "dagster",
                 "api",
                 "launch_scheduled_execution",
                 "/tmp/launch_scheduled_execution_output",  # https://bugs.python.org/issue20074 prevents using /dev/stdout
@@ -140,7 +140,7 @@ class K8sScheduler(Scheduler, ConfigurableClass):
             schedule=external_schedule.cron_schedule, job_template=job_template
         )
 
-        schedule_origin_id = external_schedule.get_origin_id()
+        schedule_origin_id = external_schedule.get_external_origin_id()
         cron_job = kubernetes.client.V1beta1CronJob(
             spec=cron_job_spec, metadata={"name": schedule_origin_id}
         )
@@ -165,7 +165,7 @@ class K8sScheduler(Scheduler, ConfigurableClass):
         self._start_cron_job(external_schedule)
 
         # Verify that the cron job is running
-        cron_job = self.get_cron_job(schedule_origin_id=external_schedule.get_origin_id())
+        cron_job = self.get_cron_job(schedule_origin_id=external_schedule.get_external_origin_id())
         if not cron_job:
             raise DagsterSchedulerError(
                 "Attempted to add K8s CronJob for schedule {schedule_name}, but failed. "
